" Vim Keymap file for Serbian characters, classical variant, UTF-8 encoding
"
" Maintainer:   Aleksandar Veselinovic <aleksa@cs.cmu.edu>
" URL:		    http://www.cs.cmu.edu/~aleksa/personal/vim/keymap/serbian-UTF-8.vim
" Last Changed: 2002 Mar 29

scriptencoding UTF-8

let b:keymap_name = "serbian-UTF-8"

loadkeymap
Q	Љ
W	Њ
E	Е
R	Р
T	Т
Y	З
U	У
I	И
O	О
P	П
{	Ш
}	Ђ
q	љ
w	њ
e	е
r	р
t	т
y	з
u	у
i	и
o	о
p	п
[	ш
]	ђ
A	А
S	С
D	Д
F	Ф
G	Г
H	Х
J	Ј
K	К
L	Л
:	Ч
\"	Ћ
\|	Ж
a	а
s	с
d	д
f	ф
g	г
h	х
j	ј
k	к
l	л
;	ч
'	ћ
\\	ж
"Z	З
X	Џ
C	Ц
V	В
B	Б
N	Н
M	М
"z	з
x	џ
c	ц
v	в
b	б
n	н
m	м

<	;
>	:
/	-
_	?
,,	„
''	”

E$	<char-0x20AC>	" EURO SIGN
--	<char-0x2013>	" endash
---	<char-0x2014>	" emdash

" @	"
" #	'
" $	*
" %	:
" ^	,
" &amp;	.
" *	;

